@@ -16,7 +16,7 @@ def route_matches(r1, r2, fields=('dst', 'metric', 'proto'), verbose=False, inde
     return _matches(r1, r2, fields, verbose, indent)
 
 
-def rule_matches(r1, r2, fields=('priority', 'iif', 'oif', 'dst', 'metric', 'proto'), verbose=False, indent=""):
+def rule_matches(r1, r2, fields=('priority', 'iif', 'oif', 'dst', 'metric', 'protocol'), verbose=False, indent=""):
     return _matches(r1, r2, fields, verbose, indent)
 
 
@@ -120,7 +120,12 @@ class Tables(collections.abc.Mapping):
                 continue
 
             # skip ignored routes
-            if route['proto'] in ignores.get('protos', []):
+            ignore = False
+            for iroute in ignores:
+                if route_matches(route, iroute, iroute.keys()):
+                    ignore = True
+                    break
+            if ignore:
                 continue
 
             if route['dst_len'] > 0:
@@ -243,7 +248,12 @@ class Tables(collections.abc.Mapping):
                             route['dst'], err.args[1]))
 
             for route in kroutes:
-                if route['proto'] in ignores.get('protos', []):
+                ignore = False
+                for iroute in ignores:
+                    if route_matches(route, iroute, iroute.keys()):
+                        ignore = True
+                        break
+                if ignore:
                     continue
 
                 logger.info(
@@ -296,7 +306,7 @@ class Rules():
             'tos': rule.get('tos', 0),
         }
 
-        if type(rule['action']) == str:
+        if 'action' in rule and type(rule['action']) == str:
             ru['action'] = {
                 "to_tbl": "FR_ACT_TO_TBL",
                 "unicast": "FR_ACT_UNICAST",
@@ -304,9 +314,9 @@ class Rules():
                 "unreachable": "FR_ACT_UNREACHABLE",
                 "prohibit": "FR_ACT_PROHIBIT",
                 "nat": "FR_ACT_NAT",
-            }.get(rule['action'])
+            }.get(rule['action'], rule['action'])
         else:
-            ru['action'] = rule.get('action'.lower(), "FR_ACTION_TO_TBL")
+            ru['action'] = rule.get('action'.lower(), "FR_ACT_TO_TBL")
 
         if 'fwmark' in rule:
             ru['fwmark'] = rule['fwmark']
@@ -364,6 +374,47 @@ class Rules():
             rules.append(ru)
         return rules
 
+    def show_rules(self, ignores):
+        rules = []
+        for rule in self.kernel_rules():
+            # skip ignored routes
+            ignore = False
+            for irule in ignores:
+                if 'proto' in irule:
+                    irule['protocol'] = irule['proto']
+                    del irule['proto']
+                if rule_matches(rule, irule, irule.keys()):
+                    ignore = True
+                    break
+            if ignore:
+                continue
+
+            rule['action'] = {
+                "FR_ACT_TO_TBL": "to_tbl",
+                "FR_ACT_UNICAST": "unicast",
+                "FR_ACT_BLACKHOLE": "blackhole",
+                "FR_ACT_UNREACHABLE": "unreachable",
+                "FR_ACT_PROHIBIT": "prohibit",
+                "FR_ACT_NAT": "nat",
+            }.get(rule['action'], rule['action'])
+
+
+            if 'protocol' in rule:
+                rule['proto'] = rule['protocol']
+                del rule['protocol']
+
+            if rule['src_len'] > 0:
+                rule['from'] = ip_network(
+                    '{}/{}'.format(rule['src'], rule['src_len'])).with_prefixlen
+            del rule['src']
+            del rule['src_len']
+            del rule['family']
+            del rule['tos']
+
+            rules.append(rule)
+
+        return rules
+
     def apply(self, ignores, do_apply):
         logger.info('\nconfiguring routing rules...')
         krules = self.kernel_rules()
@@ -391,7 +442,15 @@ class Rules():
                     logger.warning('rule setup failed: {}'.format(err.args[1]))
 
         for rule in krules:
-            if rule['protocol'] in ignores.get('protos', []):
+            ignore = False
+            for irule in ignores:
+                if 'proto' in irule:
+                    irule['protocol'] = irule['proto']
+                    del irule['proto']
+                if rule_matches(rule, irule, irule.keys()):
+                    ignore = True
+                    break
+            if ignore:
                 continue
 
             logger.info(
